==> moodle_1.3.1.orig.tar.gz: moodle/lang/pt/calendar.php <==
<?PHP // $Id: calendar.php,v 1.1 2004/04/27 12:40:13 villate Exp $ 
      // calendar.php - created with Moodle 1.3 development (2004042600)


$string['april'] = 'Abril';
$string['august'] = 'Agosto';
$string['calendar'] = 'Calendrio';
$string['calendarheading'] = 'Calendrio de $a';
$string['clickhide'] = 'click para esconder';
$string['clickshow'] = 'click para mostrar';
$string['confirmeventdelete'] = 'Tem a certeza que deseja apagar este evento?';
$string['courseevents'] = 'Eventos da disciplina';
$string['dayview'] = 'Listagem diria';
$string['daywithnoevents'] = 'No h eventos marcados nesta data';
$string['december'] = 'Dezembro';
$string['default'] = 'Por omisso';
$string['deleteevent'] = 'Apagar evento';
$string['detailedmonthview'] = 'Listagem mensal detalhada';
$string['durationnone'] = 'Sem durao';
$string['durationuntil'] = 'At';
$string['editevent'] = 'A editar evento';
$string['errorbeforecoursestart'] = 'No  possvel definir eventos antes da data de incio da disciplina';
$string['errorinvaliddate'] = 'Data no vlida';
$string['errornodescription'] = ' precisa uma descrio';
$string['errornoeventname'] = ' preciso um nome';
$string['eventdate'] = 'Data';
$string['eventdescription'] = 'Descrio';
$string['eventduration'] = 'Durao';
$string['eventendtime'] = 'Hora do fim';
$string['eventinstanttime'] = 'Tempo';
$string['eventkind'] = 'Tipo de evento';
$string['eventname'] = 'Nome';
$string['eventsfor'] = '$a eventos';
$string['eventstarttime'] = 'Hora de incio';
$string['eventtime'] = 'Tempo';
$string['eventview'] = 'Detalhes do evento';
$string['expired'] = 'Expirou';
$string['explain_lookahead'] = 'Esta preferncia define o nmero (mximo) de dias no  futuro em que dever comear um evento para que seja apresentado entre os prximos eventos. Eventos que comeem mais tarde nunca sero apresentados na lista de prximos eventos. Por favor repare que <strong>no existe garantia</strong> garantia de que todos o eventos a comear nesse intervalo seja apresentados; se houver demasiados eventos (mais do que o \"Nmero mximo de eventos\") os eventos mais distantes no sero apresentados.';
$string['explain_maxevents'] = 'Esta preferncia limita o nmero mximo de prximos eventos que podero ser apresentados na lista de prximos eventos. Se escolher aqui um nmero muito grande,  possvel que a lista completa ocupe demasiado espao no seu ecran.';
$string['explain_startwday'] = 'Esta preferncia configura a forma como sero apresentados os calendrios mensais. Use-a para fazer com que o calendrio aparea numa forma que lhe seja mais familiar.';
$string['explain_timeformat'] = 'Esta preferncia controla a forma como as horas so apresentadas no calendrio. Pode escolher entre formato de 12 ou 24 horas. Se escolher o valor por \"omisso\", o formato ser definido automaticamente de acordo com a lngua que usar no seu stio.';
$string['february'] = 'Fevereiro';
$string['fri'] = 'Sex';
$string['friday'] = 'Sexta';
$string['globalevents'] = 'Eventos globais';
$string['groupevents'] = 'Eventos de grupo';
$string['hidden'] = 'oculto';
$string['january'] = 'Janeiro';
$string['july'] = 'Julho';
$string['june'] = 'Junho';
$string['manyevents'] = '$a eventos';
$string['march'] = 'Maro';
$string['may'] = 'Maio';
$string['mon'] = 'Seg';
$string['monday'] = 'Segunda';
$string['monthlyview'] = 'Listagem mensal';
$string['newevent'] = 'Novo evento';
$string['noupcomingevents'] = 'No h eventos prximos';
$string['november'] = 'Novembro';
$string['october'] = 'Outubro';
$string['oneevent'] = '1 evento';
$string['pref_lookahead'] = 'Viso prvia de prximos eventos';
$string['pref_maxevents'] = 'Nmero mximo de prximos eventos';
$string['pref_startwday'] = 'Primeiro dia da semana';
$string['pref_timeformat'] = 'Formato do horrio';
$string['preferences'] = 'Preferncias';
$string['preferences_available'] = 'As suas preferncias pessoais';
$string['sat'] = 'Sab';
$string['saturday'] = 'Sbado';
$string['september'] = 'Setembro';
$string['shown'] = 'mostrado';
$string['spanningevents'] = 'Eventos a decorrer';
$string['sun'] = 'Dom';
$string['sunday'] = 'Domingo';
$string['thu'] = 'Qui';
$string['thursday'] = 'Quinta';
$string['timeformat_12'] = '12 horas (am/pm)';
$string['timeformat_24'] = '24 horas';
$string['today'] = 'Hoje';
$string['tomorrow'] = 'Amanh';
$string['tt_deleteevent'] = 'Apagar evento';
$string['tt_editevent'] = 'Editar evento';
$string['tt_hidecourse'] = 'Mostram-se eventos da disciplina (carregue para ocult-los)';
$string['tt_hideglobal'] = 'Mostram-se eventos globais (carregue para ocult-los)';
$string['tt_hidegroups'] = 'Mostram-se eventos de grupo (carregue para ocult-los)';
$string['tt_hideuser'] = 'Mostram-se eventos de utilizador (carregue para ocult-los)';
$string['tt_showcourse'] = 'Eventos da disciplina ocultos (carregue para mostr-los)';
$string['tt_showglobal'] = 'Eventos globais ocultos (carregue para mostr-los)';
$string['tt_showgroups'] = 'Eventos de grupo ocultos (carregue para mostr-los)';
$string['tt_showuser'] = 'Eventos do utilizador ocultos (carregue para mostr-los)';
$string['tue'] = 'Ter';
$string['tuesday'] = 'Tera';
$string['typecourse'] = 'Evento da disciplina';
$string['typegroup'] = 'Evento de grupo';
$string['typesite'] = 'Evento do stio';
$string['typeuser'] = 'Evento do utilizador';
$string['upcomingevents'] = 'Prximos eventos';
$string['userevents'] = 'Eventos do utilizador';
$string['wed'] = 'Qua';
$string['wednesday'] = 'Quarta';
$string['yesterday'] = 'Ontem';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.4 development (2004062600)


$string['calendar'] = 'Calendrio';
$string['calendarheading'] = 'Calendrio de $a';
$string['clickhide'] = 'click para esconder';
$string['clickshow'] = 'click para mostrar';
$string['confirmeventdelete'] = 'Tem a certeza que deseja apagar este evento?';
$string['courseevents'] = 'Eventos da disciplina';
$string['dayview'] = 'Listagem diria';
$string['daywithnoevents'] = 'No h eventos marcados nesta data';
$string['default'] = 'Por omisso';
$string['deleteevent'] = 'Apagar evento';
$string['detailedmonthview'] = 'Listagem mensal detalhada';
$string['durationminutes'] = 'Durao em minutos';
$string['durationnone'] = 'Sem durao';
$string['durationuntil'] = 'At';
$string['editevent'] = 'A editar evento';
$string['errorbeforecoursestart'] = 'No  possvel definir eventos antes da data de incio da disciplina';
$string['errorinvaliddate'] = 'Data no vlida';
$string['errorinvalidminutes'] = 'Indique a durao, em minutos, por meio de um nmero entre 1 e 999.';
$string['errorinvalidrepeats'] = 'Indique o nmero de eventos por meio de um nmero entre 1 e 99.';
$string['errornodescription'] = ' precisa uma descrio';
$string['errornoeventname'] = ' preciso um nome';
$string['eventdate'] = 'Data';
$string['eventdescription'] = 'Descrio';
$string['eventduration'] = 'Durao';
$string['eventendtime'] = 'Hora do fim';
$string['eventinstanttime'] = 'Tempo';
$string['eventkind'] = 'Tipo de evento';
$string['eventname'] = 'Nome';
$string['eventrepeat'] = 'Repete-se';
$string['eventsfor'] = '$a eventos';
$string['eventstarttime'] = 'Hora de incio';
$string['eventtime'] = 'Tempo';
$string['eventview'] = 'Detalhes do evento';
$string['expired'] = 'Expirou';
$string['explain_lookahead'] = 'Esta preferncia define o nmero (mximo) de dias no  futuro em que dever comear um evento para que seja apresentado entre os prximos eventos. Eventos que comeem mais tarde nunca sero apresentados na lista de prximos eventos. Por favor repare que <strong>no existe garantia</strong> garantia de que todos o eventos a comear nesse intervalo seja apresentados; se houver demasiados eventos (mais do que o \"Nmero mximo de eventos\") os eventos mais distantes no sero apresentados.';
$string['explain_maxevents'] = 'Esta preferncia limita o nmero mximo de prximos eventos que podero ser apresentados na lista de prximos eventos. Se escolher aqui um nmero muito grande,  possvel que a lista completa ocupe demasiado espao no seu ecran.';
$string['explain_startwday'] = 'Esta preferncia configura a forma como sero apresentados os calendrios mensais. Use-a para fazer com que o calendrio aparea numa forma que lhe seja mais familiar.';
$string['explain_timeformat'] = 'Esta preferncia controla a forma como as horas so apresentadas no calendrio. Pode escolher entre formato de 12 ou 24 horas. Se escolher o valor por \"omisso\", o formato ser definido automaticamente de acordo com a lngua que usar no seu stio.';
$string['fri'] = 'Sex';
$string['friday'] = 'Sexta';
$string['globalevents'] = 'Eventos globais';
$string['gotocalendar'] = 'Ir ao calendrio';
$string['groupevents'] = 'Eventos de grupo';
$string['hidden'] = 'oculto';
$string['manyevents'] = '$a eventos';
$string['mon'] = 'Seg';
$string['monday'] = 'Segunda';
$string['monthlyview'] = 'Listagem mensal';
$string['newevent'] = 'Novo evento';
$string['noupcomingevents'] = 'No h eventos prximos';
$string['oneevent'] = '1 evento';
$string['pref_lookahead'] = 'Viso prvia de prximos eventos';
$string['pref_maxevents'] = 'Nmero mximo de prximos eventos';
$string['pref_startwday'] = 'Primeiro dia da semana';
$string['pref_timeformat'] = 'Formato do horrio';
$string['preferences'] = 'Preferncias';
$string['preferences_available'] = 'As suas preferncias pessoais';
$string['repeatnone'] = 'Sem repeties';
$string['repeatweeksl'] = 'Repete-se semanalmente, num total de';
$string['repeatweeksr'] = 'eventos';
$string['sat'] = 'Sab';
$string['saturday'] = 'Sbado';
$string['shown'] = 'mostrado';
$string['spanningevents'] = 'Eventos a decorrer';
$string['sun'] = 'Dom';
$string['sunday'] = 'Domingo';
$string['thu'] = 'Qui';
$string['thursday'] = 'Quinta';
$string['timeformat_12'] = '12 horas (am/pm)';
$string['timeformat_24'] = '24 horas';
$string['today'] = 'Hoje';
$string['tomorrow'] = 'Amanh';
$string['tt_deleteevent'] = 'Apagar evento';
$string['tt_editevent'] = 'Editar evento';
$string['tt_hidecourse'] = 'Mostram-se eventos da disciplina (carregue para ocult-los)';
$string['tt_hideglobal'] = 'Mostram-se eventos globais (carregue para ocult-los)';
$string['tt_hidegroups'] = 'Mostram-se eventos de grupo (carregue para ocult-los)';
$string['tt_hideuser'] = 'Mostram-se eventos de utilizador (carregue para ocult-los)';
$string['tt_showcourse'] = 'Eventos da disciplina ocultos (carregue para mostr-los)';
$string['tt_showglobal'] = 'Eventos globais ocultos (carregue para mostr-los)';
$string['tt_showgroups'] = 'Eventos de grupo ocultos (carregue para mostr-los)';
$string['tt_showuser'] = 'Eventos do utilizador ocultos (carregue para mostr-los)';
$string['tue'] = 'Ter';
$string['tuesday'] = 'Tera';
$string['typecourse'] = 'Evento da disciplina';
$string['typegroup'] = 'Evento de grupo';
$string['typesite'] = 'Evento do stio';
$string['typeuser'] = 'Evento do utilizador';
$string['upcomingevents'] = 'Prximos eventos';
$string['userevents'] = 'Eventos do utilizador';
$string['wed'] = 'Qua';
$string['wednesday'] = 'Quarta';
$string['yesterday'] = 'Ontem';

?>
